@@ -1,4 +1,5 @@
 # Copyright 2014 - Mirantis, Inc.
+# Copyright 2020 Nokia Software.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -12,7 +13,7 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import json
+from oslo_serialization import jsonutils
 
 from mistralclient.api import base
 
@@ -24,16 +25,19 @@ class ActionExecution(base.Resource):
 class ActionExecutionManager(base.ResourceManager):
     resource_class = ActionExecution
 
-    def create(self, name, input=None, **params):
+    def create(self, name, input=None, namespace='', **params):
         self._ensure_not_empty(name=name)
 
         data = {'name': name}
 
         if input:
-            data['input'] = json.dumps(input)
+            data['input'] = jsonutils.dumps(input)
 
         if params:
-            data['params'] = json.dumps(params)
+            data['params'] = jsonutils.dumps(params)
+
+        if namespace:
+            data['workflow_namespace'] = namespace
 
         return self._create(
             '/action_executions',
