@@ -61,6 +61,7 @@ class List(base.MistralLister):
 
     def _get_resources(self, parsed_args):
         mistral_client = self.app.client_manager.workflow_engine
+
         return mistral_client.workbooks.list(
             marker=parsed_args.marker,
             limit=parsed_args.limit,
@@ -90,6 +91,7 @@ class Get(command.ShowOne):
 
     def take_action(self, parsed_args):
         mistral_client = self.app.client_manager.workflow_engine
+
         workbook = mistral_client.workbooks.get(
             parsed_args.workbook,
             parsed_args.namespace
@@ -128,6 +130,7 @@ class Create(command.ShowOne):
         scope = 'public' if parsed_args.public else 'private'
 
         mistral_client = self.app.client_manager.workflow_engine
+
         workbook = mistral_client.workbooks.create(
             parsed_args.definition.read(),
             namespace=parsed_args.namespace,
@@ -155,9 +158,10 @@ class Delete(command.Command):
 
     def take_action(self, parsed_args):
         mistral_client = self.app.client_manager.workflow_engine
+
         utils.do_action_on_many(
-            lambda s: mistral_client.workbooks.delete(s,
-                                                      parsed_args.namespace),
+            lambda s:
+                mistral_client.workbooks.delete(s, parsed_args.namespace),
             parsed_args.workbook,
             "Request to delete workbook %s has been accepted.",
             "Unable to delete the specified workbook(s)."
@@ -193,6 +197,7 @@ class Update(command.ShowOne):
         scope = 'public' if parsed_args.public else 'private'
 
         mistral_client = self.app.client_manager.workflow_engine
+
         workbook = mistral_client.workbooks.update(
             parsed_args.definition.read(),
             namespace=parsed_args.namespace,
@@ -245,6 +250,7 @@ class Validate(command.ShowOne):
 
     def take_action(self, parsed_args):
         mistral_client = self.app.client_manager.workflow_engine
+
         result = mistral_client.workbooks.validate(
             parsed_args.definition.read()
         )
