@@ -14,7 +14,6 @@
 #    limitations under the License.
 
 import argparse
-import logging
 
 from cliff import command
 from cliff import show
@@ -23,55 +22,67 @@ from mistralclient.commands.v2 import base
 from mistralclient import utils
 
 
-LOG = logging.getLogger(__name__)
+class WorkflowFormatter(base.MistralFormatter):
+    COLUMNS = [
+        ('id', 'ID'),
+        ('name', 'Name'),
+        ('namespace', 'Namespace'),
+        ('project_id', 'Project ID'),
+        ('tags', 'Tags'),
+        ('input', 'Input'),
+        ('scope', 'Scope'),
+        ('created_at', 'Created at'),
+        ('updated_at', 'Updated at')
+    ]
 
+    @staticmethod
+    def format(workflow=None, lister=False):
+        if workflow:
+            tags = getattr(workflow, 'tags', None) or []
 
-def format_list(workflow=None):
-    return format(workflow, lister=True)
+            data = (
+                workflow.id,
+                workflow.name,
+                workflow.namespace,
+                workflow.project_id,
+                base.wrap(', '.join(tags)) or '<none>',
+                workflow.input if not lister else base.cut(workflow.input),
+                workflow.scope,
+                workflow.created_at
+            )
 
-
-def format(workflow=None, lister=False):
-    columns = (
-        'ID',
-        'Name',
-        'Project ID',
-        'Tags',
-        'Input',
-        'Created at',
-        'Updated at'
-    )
-
-    if workflow:
-        tags = getattr(workflow, 'tags', None) or []
-
-        data = (
-            workflow.id,
-            workflow.name,
-            workflow.project_id,
-            base.wrap(', '.join(tags)) or '<none>',
-            workflow.input if not lister else base.cut(workflow.input),
-            workflow.created_at
-        )
-
-        if hasattr(workflow, 'updated_at'):
-            data += (workflow.updated_at,)
+            if hasattr(workflow, 'updated_at'):
+                data += (workflow.updated_at,)
+            else:
+                data += (None,)
         else:
-            data += (None,)
-    else:
-        data = (tuple('<none>' for _ in range(len(columns))),)
+            data = (tuple('' for _ in range(len(WorkflowFormatter.COLUMNS))),)
 
-    return columns, data
+        return WorkflowFormatter.headings(), data
 
 
 class List(base.MistralLister):
     """List all workflows."""
 
     def _get_format_function(self):
-        return format_list
+        return WorkflowFormatter.format_list
+
+    def get_parser(self, prog_name):
+        parser = super(List, self).get_parser(prog_name)
+
+        return parser
 
     def _get_resources(self, parsed_args):
         mistral_client = self.app.client_manager.workflow_engine
-        return mistral_client.workflows.list()
+
+        return mistral_client.workflows.list(
+            marker=parsed_args.marker,
+            limit=parsed_args.limit,
+            sort_keys=parsed_args.sort_keys,
+            sort_dirs=parsed_args.sort_dirs,
+            fields=WorkflowFormatter.fields(),
+            **base.get_filters(parsed_args)
+        )
 
 
 class Get(show.ShowOne):
@@ -80,15 +91,25 @@ class Get(show.ShowOne):
     def get_parser(self, prog_name):
         parser = super(Get, self).get_parser(prog_name)
 
-        parser.add_argument('identifier', help='Workflow ID or name.')
+        parser.add_argument('workflow', help='Workflow ID or name.')
+        parser.add_argument(
+            '--namespace',
+            nargs='?',
+            default='',
+            help="Namespace to get the workflow from.",
+        )
 
         return parser
 
     def take_action(self, parsed_args):
         mistral_client = self.app.client_manager.workflow_engine
-        wf = mistral_client.workflows.get(parsed_args.identifier)
 
-        return format(wf)
+        wf = mistral_client.workflows.get(
+            parsed_args.workflow,
+            parsed_args.namespace
+        )
+
+        return WorkflowFormatter.format(wf)
 
 
 class Create(base.MistralLister):
@@ -102,6 +123,12 @@ class Create(base.MistralLister):
             type=argparse.FileType('r'),
             help='Workflow definition file.'
         )
+        parser.add_argument(
+            '--namespace',
+            nargs='?',
+            default='',
+            help="Namespace to create the workflow within.",
+        )
         parser.add_argument(
             '--public',
             action='store_true',
@@ -111,7 +138,7 @@ class Create(base.MistralLister):
         return parser
 
     def _get_format_function(self):
-        return format_list
+        return WorkflowFormatter.format_list
 
     def _validate_parsed_args(self, parsed_args):
         if not parsed_args.definition:
@@ -120,10 +147,12 @@ class Create(base.MistralLister):
 
     def _get_resources(self, parsed_args):
         scope = 'public' if parsed_args.public else 'private'
+
         mistral_client = self.app.client_manager.workflow_engine
 
         return mistral_client.workflows.create(
             parsed_args.definition.read(),
+            namespace=parsed_args.namespace,
             scope=scope
         )
 
@@ -135,18 +164,26 @@ class Delete(command.Command):
         parser = super(Delete, self).get_parser(prog_name)
 
         parser.add_argument(
-            'identifier',
+            'workflow',
             nargs='+',
             help='Name or ID of workflow(s).'
         )
 
+        parser.add_argument(
+            '--namespace',
+            nargs='?',
+            default=None,
+            help="Namespace to delete the workflow from.",
+        )
+
         return parser
 
     def take_action(self, parsed_args):
         mistral_client = self.app.client_manager.workflow_engine
         utils.do_action_on_many(
-            lambda s: mistral_client.workflows.delete(s),
-            parsed_args.identifier,
+            lambda s: mistral_client.workflows.delete(s,
+                                                      parsed_args.namespace),
+            parsed_args.workflow,
             "Request to delete workflow %s has been accepted.",
             "Unable to delete the specified workflow(s)."
         )
@@ -163,7 +200,16 @@ class Update(base.MistralLister):
             type=argparse.FileType('r'),
             help='Workflow definition'
         )
+
         parser.add_argument('--id', help='Workflow ID.')
+
+        parser.add_argument(
+            '--namespace',
+            nargs='?',
+            default='',
+            help="Namespace of the workflow.",
+        )
+
         parser.add_argument(
             '--public',
             action='store_true',
@@ -173,16 +219,18 @@ class Update(base.MistralLister):
         return parser
 
     def _get_format_function(self):
-        return format_list
+        return WorkflowFormatter.format_list
 
     def _get_resources(self, parsed_args):
         scope = 'public' if parsed_args.public else 'private'
+
         mistral_client = self.app.client_manager.workflow_engine
 
         return mistral_client.workflows.update(
             parsed_args.definition.read(),
             scope=scope,
-            id=parsed_args.id
+            id=parsed_args.id,
+            namespace=parsed_args.namespace
         )
 
 
@@ -193,28 +241,34 @@ class GetDefinition(command.Command):
         parser = super(GetDefinition, self).get_parser(prog_name)
 
         parser.add_argument('identifier', help='Workflow ID or name.')
+        parser.add_argument(
+            '--namespace',
+            nargs='?',
+            default='',
+            help="Namespace to get the workflow from.",
+        )
 
         return parser
 
     def take_action(self, parsed_args):
         mistral_client = self.app.client_manager.workflow_engine
-        wf = mistral_client.workflows.get(parsed_args.identifier)
+
+        wf = mistral_client.workflows.get(
+            parsed_args.identifier,
+            parsed_args.namespace
+        )
 
         self.app.stdout.write(wf.definition or "\n")
 
 
 class Validate(show.ShowOne):
     """Validate workflow."""
-
-    def _format(self, result=None):
+    @staticmethod
+    def _format(result=None):
         columns = ('Valid', 'Error')
 
         if result:
-            data = (result.get('valid'),)
-            if not result.get('error'):
-                data += (None,)
-            else:
-                data += (result.get('error'),)
+            data = (result.get('valid'), result.get('error'),)
         else:
             data = (tuple('<none>' for _ in range(len(columns))),)
 
@@ -233,6 +287,7 @@ class Validate(show.ShowOne):
 
     def take_action(self, parsed_args):
         mistral_client = self.app.client_manager.workflow_engine
+
         result = mistral_client.workflows.validate(
             parsed_args.definition.read()
         )
