@@ -12,16 +12,16 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
+import io
 import os
 import sys
 
-import six
-import testtools
+from oslotest import base
 
 from mistralclient import shell
 
 
-class BaseShellTests(testtools.TestCase):
+class BaseShellTests(base.BaseTestCase):
 
     def shell(self, argstr):
         orig = (sys.stdout, sys.stderr)
@@ -29,8 +29,8 @@ class BaseShellTests(testtools.TestCase):
         _old_env, os.environ = os.environ, clean_env.copy()
 
         try:
-            sys.stdout = six.moves.cStringIO()
-            sys.stderr = six.moves.cStringIO()
+            sys.stdout = io.StringIO()
+            sys.stderr = io.StringIO()
             _shell = shell.MistralShell()
             _shell.run(argstr.split())
         except SystemExit:
