@@ -11,14 +11,17 @@
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
+
 import collections
 import copy
-import json
+import importlib.resources
 
-import pkg_resources as pkg
-from six.moves.urllib import parse
-from six.moves.urllib import request
+from oslo_serialization import jsonutils
 
+from urllib import parse
+from urllib import request
+
+from mistralclient.api import base as api_base
 from mistralclient.api.v2 import environments
 from mistralclient.tests.unit.v2 import base
 from mistralclient import utils
@@ -42,22 +45,24 @@ class TestEnvironmentsV2(base.BaseClientV2Test):
     def test_create(self):
         data = copy.deepcopy(ENVIRONMENT)
 
-        mock = self.mock_http_post(content=data)
+        self.requests_mock.post(self.TEST_URL + URL_TEMPLATE,
+                                status_code=201,
+                                json=data)
         env = self.environments.create(**data)
 
         self.assertIsNotNone(env)
 
         expected_data = copy.deepcopy(data)
-        expected_data['variables'] = json.dumps(expected_data['variables'])
+        expected_data['variables'] = jsonutils.dumps(
+            expected_data['variables'])
 
-        mock.assert_called_once_with(URL_TEMPLATE, json.dumps(expected_data))
+        self.assertEqual(expected_data, self.requests_mock.last_request.json())
 
     def test_create_with_json_file_uri(self):
         # The contents of env_v2.json must be equivalent to ENVIRONMENT
-        path = pkg.resource_filename(
-            'mistralclient',
+        path = str(importlib.resources.files('mistralclient').joinpath(
             'tests/unit/resources/env_v2.json'
-        )
+        ))
 
         # Convert the file path to file URI
         uri = parse.urljoin('file:', request.pathname2url(path))
@@ -67,55 +72,80 @@ class TestEnvironmentsV2(base.BaseClientV2Test):
             )
         )
 
-        mock = self.mock_http_post(content=data)
+        self.requests_mock.post(self.TEST_URL + URL_TEMPLATE,
+                                status_code=201,
+                                json=data)
         file_input = {'file': uri}
         env = self.environments.create(**file_input)
 
         self.assertIsNotNone(env)
 
         expected_data = copy.deepcopy(data)
-        expected_data['variables'] = json.dumps(expected_data['variables'])
+        expected_data['variables'] = jsonutils.dumps(
+            expected_data['variables'])
 
-        mock.assert_called_once_with(URL_TEMPLATE, json.dumps(expected_data))
+        self.assertEqual(expected_data, self.requests_mock.last_request.json())
+
+    def test_create_without_name(self):
+        data = copy.deepcopy(ENVIRONMENT)
+        data.pop('name')
+
+        e = self.assertRaises(api_base.APIException,
+                              self.environments.create,
+                              **data)
+
+        self.assertEqual(400, e.error_code)
 
     def test_update(self):
         data = copy.deepcopy(ENVIRONMENT)
 
-        mock = self.mock_http_put(content=data)
+        self.requests_mock.put(self.TEST_URL + URL_TEMPLATE, json=data)
         env = self.environments.update(**data)
 
         self.assertIsNotNone(env)
 
         expected_data = copy.deepcopy(data)
-        expected_data['variables'] = json.dumps(expected_data['variables'])
+        expected_data['variables'] = jsonutils.dumps(
+            expected_data['variables'])
 
-        mock.assert_called_once_with(URL_TEMPLATE, json.dumps(expected_data))
+        self.assertEqual(expected_data, self.requests_mock.last_request.json())
 
     def test_update_with_yaml_file(self):
         # The contents of env_v2.json must be equivalent to ENVIRONMENT
-        path = pkg.resource_filename(
-            'mistralclient',
+        path = str(importlib.resources.files('mistralclient').joinpath(
             'tests/unit/resources/env_v2.json'
-        )
+        ))
         data = collections.OrderedDict(
             utils.load_content(
                 utils.get_contents_if_file(path)
             )
         )
+        self.requests_mock.put(self.TEST_URL + URL_TEMPLATE, json=data)
 
-        mock = self.mock_http_put(content=data)
         file_input = {'file': path}
         env = self.environments.update(**file_input)
 
         self.assertIsNotNone(env)
 
         expected_data = copy.deepcopy(data)
-        expected_data['variables'] = json.dumps(expected_data['variables'])
+        expected_data['variables'] = jsonutils.dumps(
+            expected_data['variables'])
 
-        mock.assert_called_once_with(URL_TEMPLATE, json.dumps(expected_data))
+        self.assertEqual(expected_data, self.requests_mock.last_request.json())
+
+    def test_update_without_name(self):
+        data = copy.deepcopy(ENVIRONMENT)
+        data.pop('name')
+
+        e = self.assertRaises(api_base.APIException,
+                              self.environments.update,
+                              **data)
+
+        self.assertEqual(400, e.error_code)
 
     def test_list(self):
-        mock = self.mock_http_get(content={'environments': [ENVIRONMENT]})
+        self.requests_mock.get(self.TEST_URL + URL_TEMPLATE,
+                               json={'environments': [ENVIRONMENT]})
 
         environment_list = self.environments.list()
 
@@ -128,10 +158,9 @@ class TestEnvironmentsV2(base.BaseClientV2Test):
             env.to_dict()
         )
 
-        mock.assert_called_once_with(URL_TEMPLATE)
-
     def test_get(self):
-        mock = self.mock_http_get(content=ENVIRONMENT)
+        self.requests_mock.get(self.TEST_URL + URL_TEMPLATE_NAME % 'env',
+                               json=ENVIRONMENT)
 
         env = self.environments.get('env')
 
@@ -141,11 +170,8 @@ class TestEnvironmentsV2(base.BaseClientV2Test):
             env.to_dict()
         )
 
-        mock.assert_called_once_with(URL_TEMPLATE_NAME % 'env')
-
     def test_delete(self):
-        mock = self.mock_http_delete(status_code=204)
+        self.requests_mock.delete(self.TEST_URL + URL_TEMPLATE_NAME % 'env',
+                                  status_code=204)
 
         self.environments.delete('env')
-
-        mock.assert_called_once_with(URL_TEMPLATE_NAME % 'env')
