@@ -13,7 +13,6 @@
 #    limitations under the License.
 
 import os.path
-import pkg_resources as pkg
 from urllib import parse
 from urllib import request
 
@@ -47,9 +46,11 @@ URL_TEMPLATE_NAME = '/workflows/%s'
 
 class TestWorkflowsV2(base.BaseClientV2Test):
     def test_create(self):
-        self.requests_mock.post(self.TEST_URL + URL_TEMPLATE_SCOPE,
-                                json={'workflows': [WORKFLOW]},
-                                status_code=201)
+        self.requests_mock.post(
+            self.TEST_URL + URL_TEMPLATE_SCOPE,
+            json={'workflows': [WORKFLOW]},
+            status_code=201
+        )
 
         wfs = self.workflows.create(WF_DEF)
 
@@ -62,15 +63,15 @@ class TestWorkflowsV2(base.BaseClientV2Test):
         self.assertEqual('text/plain', last_request.headers['content-type'])
 
     def test_create_with_file(self):
-        self.requests_mock.post(self.TEST_URL + URL_TEMPLATE_SCOPE,
-                                json={'workflows': [WORKFLOW]},
-                                status_code=201)
+        self.requests_mock.post(
+            self.TEST_URL + URL_TEMPLATE_SCOPE,
+            json={'workflows': [WORKFLOW]},
+            status_code=201
+        )
 
         # The contents of wf_v2.yaml must be identical to WF_DEF
-        path = pkg.resource_filename(
-            'mistralclient',
-            'tests/unit/resources/wf_v2.yaml'
-        )
+        path = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                            '..', 'resources', 'wf_v2.yaml')
 
         wfs = self.workflows.create(path)
 
@@ -83,8 +84,10 @@ class TestWorkflowsV2(base.BaseClientV2Test):
         self.assertEqual('text/plain', last_request.headers['content-type'])
 
     def test_update(self):
-        self.requests_mock.put(self.TEST_URL + URL_TEMPLATE_SCOPE,
-                               json={'workflows': [WORKFLOW]})
+        self.requests_mock.put(
+            self.TEST_URL + URL_TEMPLATE_SCOPE,
+            json={'workflows': [WORKFLOW]}
+        )
 
         wfs = self.workflows.update(WF_DEF)
 
@@ -97,8 +100,10 @@ class TestWorkflowsV2(base.BaseClientV2Test):
         self.assertEqual('text/plain', last_request.headers['content-type'])
 
     def test_update_with_id(self):
-        self.requests_mock.put(self.TEST_URL + URL_TEMPLATE_NAME % '123',
-                               json=WORKFLOW)
+        self.requests_mock.put(
+            self.TEST_URL + URL_TEMPLATE_NAME % '123',
+            json=WORKFLOW
+        )
 
         wf = self.workflows.update(WF_DEF, id='123')
 
@@ -112,14 +117,15 @@ class TestWorkflowsV2(base.BaseClientV2Test):
         self.assertEqual('text/plain', last_request.headers['content-type'])
 
     def test_update_with_file_uri(self):
-        self.requests_mock.put(self.TEST_URL + URL_TEMPLATE_SCOPE,
-                               json={'workflows': [WORKFLOW]})
+        self.requests_mock.put(
+            self.TEST_URL + URL_TEMPLATE_SCOPE,
+            json={'workflows': [WORKFLOW]}
+        )
 
         # The contents of wf_v2.yaml must be identical to WF_DEF
-        path = pkg.resource_filename(
-            'mistralclient',
-            'tests/unit/resources/wf_v2.yaml'
-        )
+        path = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                            '..', 'resources', 'wf_v2.yaml')
+
         path = os.path.abspath(path)
 
         # Convert the file path to file URI
@@ -136,8 +142,10 @@ class TestWorkflowsV2(base.BaseClientV2Test):
         self.assertEqual('text/plain', last_request.headers['content-type'])
 
     def test_list(self):
-        self.requests_mock.get(self.TEST_URL + URL_TEMPLATE,
-                               json={'workflows': [WORKFLOW]})
+        self.requests_mock.get(
+            self.TEST_URL + URL_TEMPLATE,
+            json={'workflows': [WORKFLOW]}
+        )
 
         workflows_list = self.workflows.list()
 
@@ -151,9 +159,13 @@ class TestWorkflowsV2(base.BaseClientV2Test):
         )
 
     def test_list_with_pagination(self):
-        self.requests_mock.get(self.TEST_URL + URL_TEMPLATE,
-                               json={'workflows': [WORKFLOW],
-                                     'next': '/workflows?fake'})
+        self.requests_mock.get(
+            self.TEST_URL + URL_TEMPLATE,
+            json={
+                'workflows': [WORKFLOW],
+                'next': '/workflows?fake'
+            }
+        )
 
         workflows_list = self.workflows.list(
             limit=1,
@@ -171,8 +183,10 @@ class TestWorkflowsV2(base.BaseClientV2Test):
         self.assertEqual(['asc'], last_request.qs['sort_dirs'])
 
     def test_list_with_no_limit(self):
-        self.requests_mock.get(self.TEST_URL + URL_TEMPLATE,
-                               json={'workflows': [WORKFLOW]})
+        self.requests_mock.get(
+            self.TEST_URL + URL_TEMPLATE,
+            json={'workflows': [WORKFLOW]}
+        )
 
         workflows_list = self.workflows.list(limit=-1)
 
@@ -184,6 +198,7 @@ class TestWorkflowsV2(base.BaseClientV2Test):
 
     def test_get(self):
         url = self.TEST_URL + URL_TEMPLATE_NAME % 'wf'
+
         self.requests_mock.get(url, json=WORKFLOW)
 
         wf = self.workflows.get('wf')
@@ -195,7 +210,9 @@ class TestWorkflowsV2(base.BaseClientV2Test):
         )
 
     def test_delete(self):
-        url = self.TEST_URL + URL_TEMPLATE_NAME % 'wf'
-        self.requests_mock.delete(url, status_code=204)
+        self.requests_mock.delete(
+            self.TEST_URL + URL_TEMPLATE_NAME % 'wf',
+            status_code=204
+        )
 
         self.workflows.delete('wf')
